package
Version:
v0.0.0-...-00f2186
Opens a new window with list of versions in this module.
Published: Feb 25, 2024
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Filter[T any](ss []T, predicate func(T) bool) (ret []T)
func (r *Stack[T]) Pop() T
Source Files
¶
Click to show internal directories.
Click to hide internal directories.